//Создание задачи диспетчерского вызова прочих задач
function ManageSystemFormalModelingProject(AfterRegistrationTasksFunction,..//Функция, вызываемая после регистрации задач
                                           ErrorFunction,..//Функция нештатных ситуаций
                                           ReadFunction,..//Функция получения сообщения
                                           DisplayFunction,..//Функция отправки сообщения
                                           TaskDisplayFunction,..//Функция отправки сообщения от задач
                                           PointReadFunction,..//Функция получения сообщения с точки
                                           PointDisplayFunction,..//Функция отправки сообщения на точку
                                           IsRegisteredPointFunction,..//Функция проверки регистрации точки обмена сообщениями
                                           SelectLaunchTaskForNode,..//Функция выбора задачи для запуска на текущем вычислительном узле
                                           ProjectDirectory,..//Имя директории проекта
                                           tasksSplit,..//Разделитель доступных задач
                                           pauseSeconds..//Время паузы (в секундах)
                                           )
    //Анализируем аргументы
    nArg = argn(2);
    if nArg < 9 then
        error('the function ManageSystemFormalModelingProject takes 9, 10, 11 or 12 arguments');
    end
    select nArg
    case 9 then
        ProjectDirectory = pwd();
        tasksSplit = ',';
        pauseSeconds = 0;
    case 10 then
        if type(ProjectDirectory) == 1 then
            pauseSeconds = ProjectDirectory;
            ProjectDirectory = pwd();
        else
            pauseSeconds = 0;
        end
        tasksSplit = ',';
    case 11 then
        if type(tasksSplit) == 1 then
            pauseSeconds = tasksSplit;
            tasksSplit = ',';
        else
            pauseSeconds = 0;
        end
    end
    
    //Обрабатываем функцию считывания
    select type(ReadFunction)
    case 10 then
        execstr('readFunction = ' + ReadFunction);
    case 15 then
        //Получаем имя функции отображения и ее параметры
        rFunction = ReadFunction(1);
        rFunctionParametrs = ReadFunction(2:$);
        
        //Приводим имя функции к типу функции
        execstr('rFunction = ' + rFunction);
        
        //Формируем функцию вызова
        function [msg]=readFunction(askStr)
            msg=rFunction(askStr,rFunctionParametrs(:));
        endfunction
    end
    
    //Обрабатываем функцию отображения
    select type(DisplayFunction)
    case 10 then
        execstr('displayFunction = ' + DisplayFunction);
    case 15 then
        //Получаем имя функции отображения и ее параметры
        dFunction = DisplayFunction(1);
        dFunctionParametrs = DisplayFunction(2:$);
        
        //Приводим имя функции к типу функции
        execstr('dFunction = ' + dFunction);
        
        //Формируем функцию вызова
        function displayFunction(msg)
            dFunction(msg,dFunctionParametrs(:));
        endfunction
    end
    
    //Создаем проект
    msg = readFunction('Create project? (Y/N): ');
    if or(msg == ['N','n']) then
        ProjectName = readFunction('Name of project: ');//Имя проекта
    else
        //Создаем проект
        [ProjectName,..//Имя проекта
         err,msg]=CreateSystemFormalModelingProject(DisplayFunction,..//Функция отправки сообщения
                                                    ReadFunction,..//Функция получения сообщения задачам
                                                    TaskDisplayFunction,..//Функция отправки сообщения от задач
                                                    ProjectDirectory,..//Имя директории проекта
                                                    %f);
        if err ~= 0 then
            displayFunction('ERROR: ' + msg);
        end
        
        //Удаляем точку обмена сообщениями
        DestroyTaskInformationPoint(ProjectName);
    end
    
    //Запускаем текущие задачи
    SolveAllTasks(AfterRegistrationTasksFunction,ErrorFunction,..
                  ReadFunction,DisplayFunction,PointReadFunction,..
                  PointDisplayFunction,IsRegisteredPointFunction,..
                  SelectLaunchTaskForNode,ProjectName,tasksSplit,..
                  pauseSeconds);
    
    //Получаем результат
    msg = readFunction('Receive rezults'' datas files? (Y/N): ');
    if ~or(msg == ['N','n']) then
        //Получаем имена файлов результатов
        rezultFilesNames = readFunction('Results'' files names: ');
        rezultFilesNames = stripblanks(strsplit(rezultFilesNames,','));
        
        //Получаем имя директории, куда сохраним файлы
        rezultFilesDirectoriesName = readFunction('Results'' files directory(ies) name: ');
        rezultFilesDirectoriesName = stripblanks(strsplit(rezultFilesDirectoriesName,','));
        
        //Получаем из облака файлы результатов
        [err,msg] = ReceiveDatasTasks(rezultFilesNames,..
                                      ProjectName,..
                                      rezultFilesDirectoriesName,%t,%f);
        if err ~= 0 then
            displayFunction('ERROR: ' + msg);
        end
    end
    
    //Удаляем проект
    msg = readFunction('Delete project? (Y/N): ');
    if ~or(msg == ['N','n']) then
        [err,msg] = RemoveProjects(ProjectName,%f);
        if err ~= 0 then
            displayFunction('ERROR: ' + msg);
        end
    end
endfunction
